common

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2019 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Copyright 2019 The NSQ-Operator Authors.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AssembleNsqLookupdAddresses

func AssembleNsqLookupdAddresses(nsqLookupdAddressed []string) string

func Hash

func Hash(content map[string]string) (string, error)

func NsqAdminConfigMapName

func NsqAdminConfigMapName(cluster string) string

func NsqAdminDeploymentName

func NsqAdminDeploymentName(cluster string) string

func NsqAdminLogMountPath added in v0.4.0

func NsqAdminLogMountPath(cluster string) string

func NsqLookupdConfigMapName

func NsqLookupdConfigMapName(cluster string) string

func NsqLookupdDeploymentName

func NsqLookupdDeploymentName(cluster string) string

func NsqLookupdLogMountPath added in v0.4.0

func NsqLookupdLogMountPath(cluster string) string

func NsqdConfigMapName added in v0.4.0

func NsqdConfigMapName(cluster string) string

func NsqdLogMountPath added in v0.4.0

func NsqdLogMountPath(cluster string) string

func NsqdStatefulSetName

func NsqdStatefulSetName(cluster string) string

func NsqdVolumeClaimTemplatesName added in v0.4.0

func NsqdVolumeClaimTemplatesName(cluster string) string

func QpsReporterLogDir added in v0.5.0

func QpsReporterLogDir(cluster string) string

func QpsReporterLogMountPath added in v0.5.0

func QpsReporterLogMountPath(cluster string) string

Types

This section is empty.

Jump to