Documentation
¶
Overview ¶
Copyright 2019 The NSQ-Operator Authors.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
- func AssembleNsqLookupdAddresses(nsqLookupdAddressed []string) string
- func Hash(content map[string]string) (string, error)
- func NsqAdminConfigMapName(cluster string) string
- func NsqAdminDeploymentName(cluster string) string
- func NsqAdminLogMountPath(cluster string) string
- func NsqLookupdConfigMapName(cluster string) string
- func NsqLookupdDeploymentName(cluster string) string
- func NsqLookupdLogMountPath(cluster string) string
- func NsqdConfigMapName(cluster string) string
- func NsqdLogMountPath(cluster string) string
- func NsqdStatefulSetName(cluster string) string
- func NsqdVolumeClaimTemplatesName(cluster string) string
- func QpsReporterLogDir(cluster string) string
- func QpsReporterLogMountPath(cluster string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NsqAdminConfigMapName ¶
func NsqAdminDeploymentName ¶
func NsqAdminLogMountPath ¶ added in v0.4.0
func NsqLookupdConfigMapName ¶
func NsqLookupdLogMountPath ¶ added in v0.4.0
func NsqdConfigMapName ¶ added in v0.4.0
func NsqdLogMountPath ¶ added in v0.4.0
func NsqdStatefulSetName ¶
func NsqdVolumeClaimTemplatesName ¶ added in v0.4.0
func QpsReporterLogDir ¶ added in v0.5.0
func QpsReporterLogMountPath ¶ added in v0.5.0
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.