Documentation
¶
Overview ¶
package controller implements the reconcile logic for all components.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NsqAdminController ¶
type NsqAdminController struct {
// contains filtered or unexported fields
}
NsqAdminController is the reconcile implementation for NsqAdmin resources.
func NewNsqAdminController ¶
func NewNsqAdminController(opts *options.Options, kubeClientSet kubernetes.Interface, nsqClientSet nsqclientset.Interface, deploymentInformer informersappsv1.DeploymentInformer, configmapInformer informerscorev1.ConfigMapInformer, nsqInformer v1alpha1.NsqAdminInformer) *NsqAdminController
NewNsqAdminController returns a NsqAdmin controller.
func (*NsqAdminController) Run ¶
func (nac *NsqAdminController) Run(threads int, stopCh <-chan struct{}) error
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.
type NsqLookupdController ¶
type NsqLookupdController struct {
// contains filtered or unexported fields
}
NsqLookupdController is the reconcile implementation for NsqLookupd resources.
func NewNsqLookupdController ¶
func NewNsqLookupdController(opts *options.Options, kubeClientSet kubernetes.Interface, nsqClientSet nsqclientset.Interface, deploymentInformer informersappsv1.DeploymentInformer, configmapInformer informerscorev1.ConfigMapInformer, nsqInformer v1alpha1.NsqLookupdInformer) *NsqLookupdController
NewNsqLookupdController returns a NsqLookupd controller.
func (*NsqLookupdController) Run ¶
func (nlc *NsqLookupdController) Run(threads int, stopCh <-chan struct{}) error
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.
type NsqdController ¶ added in v0.4.0
type NsqdController struct {
// contains filtered or unexported fields
}
NsqdController is the controller implementation for Nsqd resources.
func NewNsqdController ¶ added in v0.4.0
func NewNsqdController(opts *options.Options, kubeClientSet kubernetes.Interface, nsqClientSet nsqclientset.Interface, statefulSetInformer informersappsv1.StatefulSetInformer, configmapInformer informerscorev1.ConfigMapInformer, nsqInformer v1alpha1.NsqdInformer) *NsqdController
NewNsqdController returns a new Nsqd controller.
func (*NsqdController) Run ¶ added in v0.4.0
func (ndc *NsqdController) Run(threads int, stopCh <-chan struct{}) error
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.
type NsqdScaleController ¶ added in v0.5.0
type NsqdScaleController struct {
// contains filtered or unexported fields
}
NsqdScaleController is the controller implementation for NsqdScale resources.
func NewNsqdScaleController ¶ added in v0.5.0
func NewNsqdScaleController(opts *options.Options, kubeClientSet kubernetes.Interface, nsqClientSet nsqclientset.Interface, nsqdScaleInformer v1alpha1.NsqdScaleInformer, nsqdInformer v1alpha1.NsqdInformer) *NsqdScaleController
NewNsqdScaleController returns a new NsqdScale controller.
func (*NsqdScaleController) Run ¶ added in v0.5.0
func (ndsc *NsqdScaleController) Run(threads int, stopCh <-chan struct{}) error
Run will set up the event handlers for types we are interested in, as well as syncing informer caches and starting workers. It will block until stopCh is closed, at which point it will shutdown the workqueue and wait for workers to finish processing their current work items.